@@ -7,27 +7,40 @@
 #ifndef NETWORKMANAGERQT_GENERIC_SETTING_H
 #define NETWORKMANAGERQT_GENERIC_SETTING_H
 
-#include <networkmanagerqt/networkmanagerqt_export.h>
 #include "setting.h"
+#include <networkmanagerqt/networkmanagerqt_export.h>
 
 #include <QString>
 
 namespace NetworkManager
 {
-
 class GenericSettingPrivate;
 
-/**
- * Represents generic setting
+/*!
+ * \class NetworkManager::GenericSetting
+ * \inheaderfile NetworkManagerQt/GenericSetting
+ * \inmodule NetworkManagerQt
+ *
+ * \brief Represents generic setting.
  */
 class NETWORKMANAGERQT_EXPORT GenericSetting : public Setting
 {
 public:
+    /*!
+     * \typedef NetworkManager::GenericSetting::Ptr
+     */
     typedef QSharedPointer<GenericSetting> Ptr;
+    /*!
+     * \typedef NetworkManager::GenericSetting::List
+     */
     typedef QList<Ptr> List;
+    /*!
+     */
     GenericSetting();
+    /*!
+     */
     explicit GenericSetting(const Ptr &other);
-    ~GenericSetting();
+    ~GenericSetting() override;
 
     QString name() const override;
 
